
/*
 * jQuery UI Menu (not officially released)
 * 
 * This widget isn't yet finished and the API is subject to change. We plan to finish
 * it for the next release. You're welcome to give it a try anyway and give us feedback,
 * as long as you're okay with migrating your code later on. We can help with that, too.
 *
 * Copyright 2010, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Menu
 *
 * Depends:
 *	jquery.ui.core.js
 *  jquery.ui.widget.js
 */
(function(jQuery) {

jQuery.widget("ui.menu", {
	_create: function() {
		var self = this;
		this.element
			.addClass("ui-menu ui-widget ui-widget-content ui-corner-all")
			.attr({
				role: "listbox",
				"aria-activedescendant": "ui-active-menuitem"
			})
			.click(function( event ) {
				if ( !jQuery( event.target ).closest( ".ui-menu-item a" ).length ) {
					return;
				}
				// temporary
				event.preventDefault();
				self.select( event );
			});
		this.refresh();
	},
	
	refresh: function() {
		var self = this;

		// don't refresh list items that are already adapted
		var items = this.element.children("li:not(.ui-menu-item):has(a)")
			.addClass("ui-menu-item")
			.attr("role", "menuitem");
		
		items.children("a")
			.addClass("ui-corner-all")
			.attr("tabindex", -1)
			// mouseenter doesn't work with event delegation
			.mouseenter(function( event ) {
				self.activate( event, jQuery(this).parent() );
			})
			.mouseleave(function() {
				self.deactivate();
			});
	},

	activate: function( event, item ) {
		this.deactivate();
		if (this.hasScroll()) {
			var offset = item.offset().top - this.element.offset().top,
				scroll = this.element.scrollTop(),
				elementHeight = this.element.height();
			if (offset < 0) {
				this.element.scrollTop( scroll + offset);
			} else if (offset >= elementHeight) {
				this.element.scrollTop( scroll + offset - elementHeight + item.height());
			}
		}
		this.active = item.eq(0)
			.children("a")
				.addClass("ui-state-hover")
				.attr("id", "ui-active-menuitem")
			.end();
		this._trigger("focus", event, { item: item });
	},

	deactivate: function() {
		if (!this.active) { return; }

		this.active.children("a")
			.removeClass("ui-state-hover")
			.removeAttr("id");
		this._trigger("blur");
		this.active = null;
	},

	next: function(event) {
		this.move("next", ".ui-menu-item:first", event);
	},

	previous: function(event) {
		this.move("prev", ".ui-menu-item:last", event);
	},

	first: function() {
		return this.active && !this.active.prevAll(".ui-menu-item").length;
	},

	last: function() {
		return this.active && !this.active.nextAll(".ui-menu-item").length;
	},

	move: function(direction, edge, event) {
		if (!this.active) {
			this.activate(event, this.element.children(edge));
			return;
		}
		var next = this.active[direction + "All"](".ui-menu-item").eq(0);
		if (next.length) {
			this.activate(event, next);
		} else {
			this.activate(event, this.element.children(edge));
		}
	},

	// TODO merge with previousPage
	nextPage: function(event) {
		if (this.hasScroll()) {
			// TODO merge with no-scroll-else
			if (!this.active || this.last()) {
				this.activate(event, this.element.children(".ui-menu-item:first"));
				return;
			}
			var base = this.active.offset().top,
				height = this.element.height(),
				result = this.element.children(".ui-menu-item").filter(function() {
					var close = jQuery(this).offset().top - base - height + jQuery(this).height();
					// TODO improve approximation
					return close < 10 && close > -10;
				});

			// TODO try to catch this earlier when scrollTop indicates the last page anyway
			if (!result.length) {
				result = this.element.children(".ui-menu-item:last");
			}
			this.activate(event, result);
		} else {
			this.activate(event, this.element.children(".ui-menu-item")
				.filter(!this.active || this.last() ? ":first" : ":last"));
		}
	},

	// TODO merge with nextPage
	previousPage: function(event) {
		if (this.hasScroll()) {
			// TODO merge with no-scroll-else
			if (!this.active || this.first()) {
				this.activate(event, this.element.children(".ui-menu-item:last"));
				return;
			}

			var base = this.active.offset().top,
				height = this.element.height();
				result = this.element.children(".ui-menu-item").filter(function() {
					var close = jQuery(this).offset().top - base + height - jQuery(this).height();
					// TODO improve approximation
					return close < 10 && close > -10;
				});

			// TODO try to catch this earlier when scrollTop indicates the last page anyway
			if (!result.length) {
				result = this.element.children(".ui-menu-item:first");
			}
			this.activate(event, result);
		} else {
			this.activate(event, this.element.children(".ui-menu-item")
				.filter(!this.active || this.first() ? ":last" : ":first"));
		}
	},

	hasScroll: function() {
		return this.element.height() < this.element[ jQuery.fn.prop ? "prop" : "attr" ]("scrollHeight");
	},

	select: function( event ) {
		this._trigger("selected", event, { item: this.active });
	}
});

}(jQuery));

/*
 * jQuery UI Slider 1.8.14
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Slider
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.mouse.js
 *	jquery.ui.widget.js
 */
(function(e,f){var g=10;e.widget("ui.slider",e.ui.mouse,{widgetEventPrefix:"slide",options:{animate:true,distance:0,max:100,min:0,orientation:"horizontal",range:false,step:1,value:0,values:null},_create:function(){var c=this,o=this.options,existingHandles=this.element.find(".ui-slider-handle").addClass("ui-state-default ui-corner-all"),handle="<a class='ui-slider-handle ui-state-default ui-corner-all' href='#'></a>",handleCount=(o.values&&o.values.length)||1,handles=[];this._keySliding=false;this._mouseSliding=false;this._animateOff=true;this._handleIndex=null;this._detectOrientation();this._mouseInit();this.element.addClass("vertex-style-slider ui-slider"+" ui-slider-"+this.orientation+" ui-widget"+" ui-widget-content"+" ui-corner-all"+(o.disabled?" ui-slider-disabled ui-disabled":""));this.range=e([]);if(o.range){if(o.range===true){if(!o.values){o.values=[this._valueMin(),this._valueMin()]}if(o.values.length&&o.values.length!==1){if(o.values.length===2){o.values=[o.values[0],o.values[1]]}else if(o.values.length===3){o.values=[o.values[0],o.values[1],o.values[2]]}else if(o.values.length===4){o.values=[o.values[0],o.values[1],o.values[2],o.values[3]]}else if(o.values.length===5){o.values=[o.values[0],o.values[1],o.values[2],o.values[3],o.values[4]]}else if(o.values.length===6){o.values=[o.values[0],o.values[1],o.values[2],o.values[3],o.values[4],o.values[5]]}}}this.range=e("<div></div>").appendTo(this.element).hide().addClass("ui-slider-range"+" ui-widget-header"+((o.range==="min"||o.range==="max")?" ui-slider-range-"+o.range:""))}for(var i=existingHandles.length;i<handleCount;i+=1){handles.push(handle)}this.handles=existingHandles.add(e(handles.join("")).appendTo(c.element));this.handle=this.handles.eq(0);this.handles.add(this.range).filter("a").click(function(a){a.preventDefault()}).hover(function(){if(!o.disabled){e(this).addClass("ui-state-hover")}},function(){e(this).removeClass("ui-state-hover")}).focus(function(){if(!o.disabled){e(".ui-slider .ui-state-focus").removeClass("ui-state-focus");e(this).addClass("ui-state-focus")}else{e(this).blur()}}).blur(function(){e(this).removeClass("ui-state-focus")});this.handles.each(function(i){e(this).data("index.ui-slider-handle",i);e(this).data("index.ui-handle-value",o.values[i])});this.handles.keydown(function(a){var b=true,index=e(this).data("index.ui-slider-handle"),allowed,curVal,newVal,step;if(c.options.disabled){return}switch(a.keyCode){case e.ui.keyCode.HOME:case e.ui.keyCode.END:case e.ui.keyCode.PAGE_UP:case e.ui.keyCode.PAGE_DOWN:case e.ui.keyCode.UP:case e.ui.keyCode.RIGHT:case e.ui.keyCode.DOWN:case e.ui.keyCode.LEFT:b=false;if(!c._keySliding){c._keySliding=true;e(this).addClass("ui-state-active");allowed=c._start(a,index);if(allowed===false){return}}break}step=c.options.step;if(c.options.values&&c.options.values.length){curVal=newVal=c.values(index)}else{curVal=newVal=c.value()}switch(a.keyCode){case e.ui.keyCode.HOME:newVal=c._valueMin();break;case e.ui.keyCode.END:newVal=c._valueMax();break;case e.ui.keyCode.PAGE_UP:newVal=c._trimAlignValue(curVal+((c._valueMax()-c._valueMin())/g));break;case e.ui.keyCode.PAGE_DOWN:newVal=c._trimAlignValue(curVal-((c._valueMax()-c._valueMin())/g));break;case e.ui.keyCode.UP:case e.ui.keyCode.RIGHT:if(curVal===c._valueMax()){return}newVal=c._trimAlignValue(curVal+step);break;case e.ui.keyCode.DOWN:case e.ui.keyCode.LEFT:if(curVal===c._valueMin()){return}newVal=c._trimAlignValue(curVal-step);break}c._slide(a,index,newVal);return b}).keyup(function(a){var b=e(this).data("index.ui-slider-handle");if(c._keySliding){c._keySliding=false;c._stop(a,b);c._change(a,b);e(this).removeClass("ui-state-active")}});this._refreshValue();this._animateOff=false},destroy:function(){this.handles.remove();this.range.remove();this.element.removeClass("ui-slider"+" ui-slider-horizontal"+" ui-slider-vertical"+" ui-slider-disabled"+" ui-widget"+" ui-widget-content"+" ui-corner-all").removeData("slider").unbind(".slider");this._mouseDestroy();return this},_mouseCapture:function(b){var o=this.options,position,normValue,distance,closestHandle,self,index,allowed,offset,mouseOverHandle;if(o.disabled){return false}this.elementSize={width:this.element.outerWidth(),height:this.element.outerHeight()};this.elementOffset=this.element.offset();position={x:b.pageX,y:b.pageY};normValue=this._normValueFromMouse(position);distance=this._valueMax()-this._valueMin()+1;self=this;this.handles.each(function(i){var a=Math.abs(normValue-self.values(i));if(distance>a){distance=a;closestHandle=e(this);index=i}});if(o.range===true&&this.values(1)===o.min||this.values(2)===o.min){index+=1;closestHandle=e(this.handles[index])}allowed=this._start(b,index);if(allowed===false){return false}this._mouseSliding=true;self._handleIndex=index;closestHandle.addClass("ui-state-active").focus();offset=closestHandle.offset();mouseOverHandle=!e(b.target).parents().andSelf().is(".ui-slider-handle");this._clickOffset=mouseOverHandle?{left:0,top:0}:{left:b.pageX-offset.left-(closestHandle.width()/2),top:b.pageY-offset.top-(closestHandle.height()/2)-(parseInt(closestHandle.css("borderTopWidth"),10)||0)-(parseInt(closestHandle.css("borderBottomWidth"),10)||0)+(parseInt(closestHandle.css("marginTop"),10)||0)};if(!this.handles.hasClass("ui-state-hover")){this._slide(b,index,normValue)}this._animateOff=true;return true},_mouseStart:function(a){return true},_mouseDrag:function(a){var b={x:a.pageX,y:a.pageY},normValue=this._normValueFromMouse(b);this._slide(a,this._handleIndex,normValue);return false},_mouseStop:function(a){this.handles.removeClass("ui-state-active");this._mouseSliding=false;this._stop(a,this._handleIndex);this._change(a,this._handleIndex);this._handleIndex=null;this._clickOffset=null;this._animateOff=false;return false},_detectOrientation:function(){this.orientation=(this.options.orientation==="vertical")?"vertical":"horizontal"},_normValueFromMouse:function(a){var b,pixelMouse,percentMouse,valueTotal,valueMouse;if(this.orientation==="horizontal"){b=this.elementSize.width;pixelMouse=a.x-this.elementOffset.left-(this._clickOffset?this._clickOffset.left:0)}else{b=this.elementSize.height;pixelMouse=a.y-this.elementOffset.top-(this._clickOffset?this._clickOffset.top:0)}percentMouse=(pixelMouse/b);if(percentMouse>1){percentMouse=1}if(percentMouse<0){percentMouse=0}if(this.orientation==="vertical"){percentMouse=1-percentMouse}valueTotal=this._valueMax()-this._valueMin();valueMouse=this._valueMin()+percentMouse*valueTotal;return this._trimAlignValue(valueMouse)},_start:function(a,b){var c={handle:this.handles[b],value:this.value()};if(this.options.values&&this.options.values.length){c.value=this.values(b);c.values=this.values()}return this._trigger("start",a,c)},_slide:function(a,b,c){var d,prevVal,nextVal,newValues,allowed;if(this.options.values&&this.options.values.length){if(this.options.values.length===2){d=this.values(b?0:1)}else{prevVal=Number(b)-1;nextVal=Number(b)+1;prevVal=this.values(prevVal);nextVal=this.values(nextVal)}if((this.options.values.length===2&&this.options.range===true)&&((b===0&&c>prevVal)||(b===1&&c<prevVal))){c=prevVal}if((this.options.values.length===3&&this.options.range===true)){if(b===0&&c>nextVal){c=nextVal}if(b===1&&c<prevVal){c=prevVal}if(b===1&&c>nextVal){c=nextVal}}if((this.options.values.length===4&&this.options.range===true)){if(b===0&&c>nextVal){c=nextVal}if(b===1&&c<prevVal){c=prevVal}if(b===1&&c>nextVal){c=nextVal}if(b===2&&c<prevVal){c=prevVal}if(b===2&&c>nextVal){c=nextVal}}if((this.options.values.length===5&&this.options.range===true)){if(b===0&&c>nextVal){c=nextVal}if(b===1&&c<prevVal){c=prevVal}if(b===1&&c>nextVal){c=nextVal}if(b===2&&c<prevVal){c=prevVal}if(b===2&&c>nextVal){c=nextVal}if(b===3&&c<prevVal){c=prevVal}if(b===3&&c>nextVal){c=nextVal}}if((this.options.values.length===6&&this.options.range===true)){if(b===0&&c>nextVal){c=nextVal}if(b===1&&c<prevVal){c=prevVal}if(b===1&&c>nextVal){c=nextVal}if(b===2&&c<prevVal){c=prevVal}if(b===2&&c>nextVal){c=nextVal}if(b===3&&c<prevVal){c=prevVal}if(b===3&&c>nextVal){c=nextVal}if(b===4&&c<prevVal){c=prevVal}if(b===4&&c>nextVal){c=nextVal}}if(c!==this.values(b)){newValues=this.values();newValues[b]=c;allowed=this._trigger("slide",a,{handle:this.handles[b],value:c,values:newValues});if(b===0){d=this.values(b?0:1);nextVal=Number(b)+1}else{d=Number(b)-1;nextVal=Number(b)+1;d=this.values(d);nextVal=this.values(nextVal)}if(allowed!==false){this.values(b,c,true)}}}else{if(c!==this.value()){allowed=this._trigger("slide",a,{handle:this.handles[b],value:c});if(allowed!==false){this.value(c)}}}},_stop:function(a,b){var c={handle:this.handles[b],value:this.value()};if(this.options.values&&this.options.values.length){c.value=this.values(b);c.values=this.values()}this._trigger("stop",a,c)},_change:function(a,b){if(!this._keySliding&&!this._mouseSliding){var c={handle:this.handles[b],value:this.value()};if(this.options.values&&this.options.values.length){c.value=this.values(b);c.values=this.values()}this._trigger("change",a,c)}},value:function(a){if(arguments.length){this.options.value=this._trimAlignValue(a);this._refreshValue();this._change(null,0);return}return this._value()},values:function(a,b){var c,newValues,i;if(arguments.length>1){this.options.values[a]=this._trimAlignValue(b);this._refreshValue();this._change(null,a);return}if(arguments.length){if(e.isArray(arguments[0])){c=this.options.values;newValues=arguments[0];for(i=0;i<c.length;i+=1){c[i]=this._trimAlignValue(newValues[i]);this._change(null,i)}this._refreshValue()}else{if(this.options.values&&this.options.values.length){return this._values(a)}else{return this.value()}}}else{return this._values()}},_setOption:function(a,b){var i,valsLength=0;if(e.isArray(this.options.values)){valsLength=this.options.values.length}e.Widget.prototype._setOption.apply(this,arguments);switch(a){case"disabled":if(b){this.handles.filter(".ui-state-focus").blur();this.handles.removeClass("ui-state-hover");this.handles.attr("disabled","disabled");this.element.addClass("ui-disabled")}else{this.handles.removeAttr("disabled");this.element.removeClass("ui-disabled")}break;case"orientation":this._detectOrientation();this.element.removeClass("ui-slider-horizontal ui-slider-vertical").addClass("ui-slider-"+this.orientation);this._refreshValue();break;case"value":this._animateOff=true;this._refreshValue();this._change(null,0);this._animateOff=false;break;case"values":this._animateOff=true;for(i=0;i<valsLength;i+=1){this._change(null,i)}this._refreshValue();this._animateOff=false;break}},_value:function(){var a=this.options.value;a=this._trimAlignValue(a);return a},_values:function(a){var b,vals,i;if(arguments.length){b=this.options.values[a];b=this._trimAlignValue(b);return b}else{vals=this.options.values.slice();for(i=0;i<vals.length;i+=1){vals[i]=this._trimAlignValue(vals[i])}return vals}},_trimAlignValue:function(a){if(a<=this._valueMin()){return this._valueMin()}if(a>=this._valueMax()){return this._valueMax()}var b=(this.options.step>0)?this.options.step:1,valModStep=(a-this._valueMin())%b;alignValue=a-valModStep;if(Math.abs(valModStep)*2>=b){alignValue+=(valModStep>0)?b:(-b)}return parseFloat(alignValue.toFixed(5))},_valueMin:function(){return this.options.min},_valueMax:function(){return this.options.max},_refreshValue:function(){var a=this.options.range,o=this.options,self=this,animate=(!this._animateOff)?o.animate:false,valPercent,_set={},lastValPercent,value,valueMin,valueMax;if(this.options.values&&this.options.values.length){this.handles.each(function(i,j){valPercent=(self.values(i)-self._valueMin())/(self._valueMax()-self._valueMin())*100;_set[self.orientation==="horizontal"?"left":"bottom"]=valPercent+"%";e(this).stop(1,1)[animate?"animate":"css"](_set,o.animate);if(self.options.range===true){if(self.orientation==="horizontal"){if(i===0){self.range.stop(1,1)[animate?"animate":"css"]({left:valPercent+"%"},o.animate)}if(i===1){self.range[animate?"animate":"css"]({width:(valPercent-lastValPercent)+"%"},{queue:false,duration:o.animate})}}else{if(i===0){self.range.stop(1,1)[animate?"animate":"css"]({bottom:(valPercent)+"%"},o.animate)}if(i===1){self.range[animate?"animate":"css"]({height:(valPercent-lastValPercent)+"%"},{queue:false,duration:o.animate})}}}lastValPercent=valPercent})}else{value=this.value();valueMin=this._valueMin();valueMax=this._valueMax();valPercent=(valueMax!==valueMin)?(value-valueMin)/(valueMax-valueMin)*100:0;_set[self.orientation==="horizontal"?"left":"bottom"]=valPercent+"%";this.handle.stop(1,1)[animate?"animate":"css"](_set,o.animate);if(a==="min"&&this.orientation==="horizontal"){this.range.stop(1,1)[animate?"animate":"css"]({width:valPercent+"%"},o.animate)}if(a==="max"&&this.orientation==="horizontal"){this.range[animate?"animate":"css"]({width:(100-valPercent)+"%"},{queue:false,duration:o.animate})}if(a==="min"&&this.orientation==="vertical"){this.range.stop(1,1)[animate?"animate":"css"]({height:valPercent+"%"},o.animate)}if(a==="max"&&this.orientation==="vertical"){this.range[animate?"animate":"css"]({height:(100-valPercent)+"%"},{queue:false,duration:o.animate})}}}});e.extend(e.ui.slider,{version:"1.8.14"})}(jQuery));

/*
 * jQuery UI Autocomplete 1.8.13
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI/Autocomplete
 *
 * Depends:
 *	jquery.ui.core.js
 *	jquery.ui.widget.js
 *	jquery.ui.position.js
 */
(function(f,g){var h=0;f.widget("ui.autocomplete",{options:{appendTo:"body",autoFocus:false,delay:300,width:180,minLength:1,position:{my:"left top",at:"left bottom",collision:"none"},source:null},pending:0,_create:function(){var d=this,doc=this.element[0].ownerDocument,suppressKeyPress;this.element.addClass("ui-autocomplete-input").attr("autocomplete","off").attr({role:"textbox","aria-autocomplete":"list","aria-haspopup":"true"}).bind("keydown.autocomplete",function(a){if(d.options.disabled||d.element.attr("readonly")){return}suppressKeyPress=false;var b=f.ui.keyCode;switch(a.keyCode){case b.PAGE_UP:d._move("previousPage",a);break;case b.PAGE_DOWN:d._move("nextPage",a);break;case b.UP:d._move("previous",a);a.preventDefault();break;case b.DOWN:d._move("next",a);a.preventDefault();break;case b.ENTER:case b.NUMPAD_ENTER:if(d.menu.active){suppressKeyPress=true;a.preventDefault()}case b.TAB:if(!d.menu.active){return}d.menu.select(a);break;case b.ESCAPE:d.element.val(d.term);d.close(a);break;default:clearTimeout(d.searching);d.searching=setTimeout(function(){if(d.term!=d.element.val()){d.selectedItem=null;d.search(null,a)}},d.options.delay);break}}).bind("keypress.autocomplete",function(a){if(suppressKeyPress){suppressKeyPress=false;a.preventDefault()}}).bind("focus.autocomplete",function(){if(d.options.disabled){return}d.selectedItem=null;d.previous=d.element.val()}).bind("blur.autocomplete",function(a){if(d.options.disabled){return}clearTimeout(d.searching);d.closing=setTimeout(function(){d.close(a);d._change(a)},150)});this._initSource();this.response=function(){return d._response.apply(d,arguments)};this.menu=f("<ul></ul>").addClass("ui-autocomplete").appendTo(f(this.options.appendTo||"body",doc)[0]).mousedown(function(b){var c=d.menu.element[0];if(!f(b.target).closest(".ui-menu-item").length){setTimeout(function(){f(document).one('mousedown',function(a){if(a.target!==d.element[0]&&a.target!==c&&!f.ui.contains(c,a.target)){d.close()}})},1)}setTimeout(function(){clearTimeout(d.closing)},13)}).menu({focus:function(a,b){var c=b.item.data("item.autocomplete");if(false!==d._trigger("focus",a,{item:c})){if(/^key/.test(a.originalEvent.type)){d.element.val(c.value)}}},selected:function(a,b){var c=b.item.data("item.autocomplete"),previous=d.previous;if(d.element[0]!==doc.activeElement){d.element.focus();d.previous=previous;setTimeout(function(){d.previous=previous;d.selectedItem=c},1)}if(false!==d._trigger("select",a,{item:c})){d.element.val(c.value)}d.term=d.element.val();d.close(a);d.selectedItem=c},blur:function(a,b){if(d.menu.element.is(":visible")&&(d.element.val()!==d.term)){d.element.val(d.term)}}}).zIndex(this.element.zIndex()+1).css({top:0,left:0,width:d.options.width}).hide().data("menu");if(f.fn.bgiframe){this.menu.element.bgiframe()}},destroy:function(){this.element.removeClass("ui-autocomplete-input").removeAttr("autocomplete").removeAttr("role").removeAttr("aria-autocomplete").removeAttr("aria-haspopup");this.menu.element.remove();f.Widget.prototype.destroy.call(this)},_setOption:function(a,b){f.Widget.prototype._setOption.apply(this,arguments);if(a==="source"){this._initSource()}if(a==="appendTo"){this.menu.element.appendTo(f(b||"body",this.element[0].ownerDocument)[0])}if(a==="disabled"&&b&&this.xhr){this.xhr.abort()}},_initSource:function(){var e=this,array,url;if(f.isArray(this.options.source)){array=this.options.source;this.source=function(a,b){b(f.ui.autocomplete.filter(array,a.term))}}else if(typeof this.options.source==="string"){url=this.options.source;this.source=function(c,d){if(e.xhr){e.xhr.abort()}e.xhr=f.ajax({url:url,data:c,dataType:"json",autocompleteRequest:++h,success:function(a,b){if(this.autocompleteRequest===h){d(a)}},error:function(){if(this.autocompleteRequest===h){d([])}}})}}else{this.source=this.options.source}},search:function(a,b){a=a!=null?a:this.element.val();this.term=this.element.val();if(a.length<this.options.minLength){return this.close(b)}clearTimeout(this.closing);if(this._trigger("search",b)===false){return}return this._search(a)},_search:function(a){this.pending++;this.element.addClass("ui-autocomplete-loading");this.source({term:a},this.response)},_response:function(a){if(!this.options.disabled&&a&&a.length){a=this._normalize(a);this._suggest(a);this._trigger("open")}else{this.close()}this.pending--;if(!this.pending){this.element.removeClass("ui-autocomplete-loading")}},close:function(a){clearTimeout(this.closing);if(this.menu.element.is(":visible")){this.menu.element.hide();this.menu.deactivate();this._trigger("close",a)}},_change:function(a){if(this.previous!==this.element.val()){this._trigger("change",a,{item:this.selectedItem})}},_normalize:function(b){if(b.length&&b[0].label&&b[0].value){return b}return f.map(b,function(a){if(typeof a==="string"){return{label:a,value:a}}return f.extend({label:a.label||a.value,value:a.value||a.label},a)})},_suggest:function(a){var b=this.menu.element.empty().zIndex(this.element.zIndex()+9);this._renderMenu(b,a);this.menu.deactivate();this.menu.refresh();b.show();this._resizeMenu();b.position(f.extend({of:this.element},this.options.position));if(this.options.autoFocus){this.menu.next(new f.Event("mouseover"))}},_resizeMenu:function(){var a=this.menu.element;a.outerWidth(Math.max(a.width('').outerWidth(),this.element.outerWidth()))},resizemenu:function(a){var b=this.menu.element;b.width(a.width).css('overflow-y',a.overflow)},_renderMenu:function(c,d){var e=this;f.each(d,function(a,b){e._renderItem(c,b)})},_renderItem:function(a,b){return f("<li></li>").data("item.autocomplete",b).append(f("<a></a>").text(b.label)).appendTo(a)},_move:function(a,b){if(!this.menu.element.is(":visible")){this.search(null,b);return}if(this.menu.first()&&/^previous/.test(a)||this.menu.last()&&/^next/.test(a)){this.element.val(this.term);this.menu.deactivate();return}this.menu[a](b)},widget:function(){return this.menu.element}});f.extend(f.ui.autocomplete,{escapeRegex:function(a){return a.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&")},filter:function(b,c){var d=new RegExp(f.ui.autocomplete.escapeRegex(c),"i");return f.grep(b,function(a){return d.test(a.label||a.value||a)})}})}(jQuery))

/**
 * Cookie plugin
 * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 */
jQuery.cookie=function(a,b,c){if(typeof b!='undefined'){c=c||{};if(b===null){b='';c.expires=-1}var d='';if(c.expires&&(typeof c.expires=='number'||c.expires.toUTCString)){var e;if(typeof c.expires=='number'){e=new Date();e.setTime(e.getTime()+(c.expires*24*60*60*1000))}else{e=c.expires}d='; expires='+e.toUTCString()}var f=c.path?'; path='+(c.path):'';var g=c.domain?'; domain='+(c.domain):'';var h=c.secure?'; secure':'';document.cookie=[a,'=',encodeURIComponent(b),d,f,g,h].join('')}else{var j=null;if(document.cookie&&document.cookie!=''){var k=document.cookie.split(';');for(var i=0;i<k.length;i++){var l=jQuery.trim(k[i]);if(l.substring(0,a.length+1)==(a+'=')){j=decodeURIComponent(l.substring(a.length+1));break}}}return j}};

/*
 * jQuery Easing v1.3 - http://gsgd.co.uk/sandbox/jquery/easing/
 * Open source under the BSD License. 
 * Copyright  2008 George McGinley Smith
 * All rights reserved.
*/
jQuery.easing['jswing'] = jQuery.easing['swing'];
jQuery.extend(jQuery.easing,{def:'easeOutQuad',swing:function(x,t,b,c,d){return jQuery.easing[jQuery.easing.def](x,t,b,c,d)},easeInQuad:function(x,t,b,c,d){return c*(t/=d)*t+b},easeOutQuad:function(x,t,b,c,d){return-c*(t/=d)*(t-2)+b},easeInOutQuad:function(x,t,b,c,d){if((t/=d/2)<1)return c/2*t*t+b;return-c/2*((--t)*(t-2)-1)+b},easeInCubic:function(x,t,b,c,d){return c*(t/=d)*t*t+b},easeOutCubic:function(x,t,b,c,d){return c*((t=t/d-1)*t*t+1)+b},easeInOutCubic:function(x,t,b,c,d){if((t/=d/2)<1)return c/2*t*t*t+b;return c/2*((t-=2)*t*t+2)+b},easeInQuart:function(x,t,b,c,d){return c*(t/=d)*t*t*t+b},easeOutQuart:function(x,t,b,c,d){return-c*((t=t/d-1)*t*t*t-1)+b},easeInOutQuart:function(x,t,b,c,d){if((t/=d/2)<1)return c/2*t*t*t*t+b;return-c/2*((t-=2)*t*t*t-2)+b},easeInQuint:function(x,t,b,c,d){return c*(t/=d)*t*t*t*t+b},easeOutQuint:function(x,t,b,c,d){return c*((t=t/d-1)*t*t*t*t+1)+b},easeInOutQuint:function(x,t,b,c,d){if((t/=d/2)<1)return c/2*t*t*t*t*t+b;return c/2*((t-=2)*t*t*t*t+2)+b},easeInSine:function(x,t,b,c,d){return-c*Math.cos(t/d*(Math.PI/2))+c+b},easeOutSine:function(x,t,b,c,d){return c*Math.sin(t/d*(Math.PI/2))+b},easeInOutSine:function(x,t,b,c,d){return-c/2*(Math.cos(Math.PI*t/d)-1)+b},easeInExpo:function(x,t,b,c,d){return(t==0)?b:c*Math.pow(2,10*(t/d-1))+b},easeOutExpo:function(x,t,b,c,d){return(t==d)?b+c:c*(-Math.pow(2,-10*t/d)+1)+b},easeInOutExpo:function(x,t,b,c,d){if(t==0)return b;if(t==d)return b+c;if((t/=d/2)<1)return c/2*Math.pow(2,10*(t-1))+b;return c/2*(-Math.pow(2,-10*--t)+2)+b},easeInCirc:function(x,t,b,c,d){return-c*(Math.sqrt(1-(t/=d)*t)-1)+b},easeOutCirc:function(x,t,b,c,d){return c*Math.sqrt(1-(t=t/d-1)*t)+b},easeInOutCirc:function(x,t,b,c,d){if((t/=d/2)<1)return-c/2*(Math.sqrt(1-t*t)-1)+b;return c/2*(Math.sqrt(1-(t-=2)*t)+1)+b},easeInElastic:function(x,t,b,c,d){var s=1.70158;var p=0;var a=c;if(t==0)return b;if((t/=d)==1)return b+c;if(!p)p=d*.3;if(a<Math.abs(c)){a=c;var s=p/4}else var s=p/(2*Math.PI)*Math.asin(c/a);return-(a*Math.pow(2,10*(t-=1))*Math.sin((t*d-s)*(2*Math.PI)/p))+b},easeOutElastic:function(x,t,b,c,d){var s=1.70158;var p=0;var a=c;if(t==0)return b;if((t/=d)==1)return b+c;if(!p)p=d*.3;if(a<Math.abs(c)){a=c;var s=p/4}else var s=p/(2*Math.PI)*Math.asin(c/a);return a*Math.pow(2,-10*t)*Math.sin((t*d-s)*(2*Math.PI)/p)+c+b},easeInOutElastic:function(x,t,b,c,d){var s=1.70158;var p=0;var a=c;if(t==0)return b;if((t/=d/2)==2)return b+c;if(!p)p=d*(.3*1.5);if(a<Math.abs(c)){a=c;var s=p/4}else var s=p/(2*Math.PI)*Math.asin(c/a);if(t<1)return-.5*(a*Math.pow(2,10*(t-=1))*Math.sin((t*d-s)*(2*Math.PI)/p))+b;return a*Math.pow(2,-10*(t-=1))*Math.sin((t*d-s)*(2*Math.PI)/p)*.5+c+b},easeInBack:function(x,t,b,c,d,s){if(s==undefined)s=1.70158;return c*(t/=d)*t*((s+1)*t-s)+b},easeOutBack:function(x,t,b,c,d,s){if(s==undefined)s=1.70158;return c*((t=t/d-1)*t*((s+1)*t+s)+1)+b},easeInOutBack:function(x,t,b,c,d,s){if(s==undefined)s=1.70158;if((t/=d/2)<1)return c/2*(t*t*(((s*=(1.525))+1)*t-s))+b;return c/2*((t-=2)*t*(((s*=(1.525))+1)*t+s)+2)+b},easeInBounce:function(x,t,b,c,d){return c-jQuery.easing.easeOutBounce(x,d-t,0,c,d)+b},easeOutBounce:function(x,t,b,c,d){if((t/=d)<(1/2.75)){return c*(7.5625*t*t)+b}else if(t<(2/2.75)){return c*(7.5625*(t-=(1.5/2.75))*t+.75)+b}else if(t<(2.5/2.75)){return c*(7.5625*(t-=(2.25/2.75))*t+.9375)+b}else{return c*(7.5625*(t-=(2.625/2.75))*t+.984375)+b}},easeInOutBounce:function(x,t,b,c,d){if(t<d/2)return jQuery.easing.easeInBounce(x,t*2,0,c,d)*.5+b;return jQuery.easing.easeOutBounce(x,t*2-d,0,c,d)*.5+c*.5+b}});

/*
 * TERMS OF USE - EASING EQUATIONS
 * Open source under the BSD License. 
 * Copyright  2001 Robert Penner
 * All rights reserved.
 * @author Alexander Farkas
 * v. 1.21
 */
//(function(e){if(!document.defaultView||!document.defaultView.getComputedStyle){var f=e.curCSS;e.curCSS=function(a,b,c){if(b==='background-position'){b='backgroundPosition'}if(b!=='backgroundPosition'||!a.currentStyle||a.currentStyle[b]){return f.apply(this,arguments)}var d=a.style;if(!c&&d&&d[b]){return d[b]}return f(a,'backgroundPositionX',c)+' '+f(a,'backgroundPositionY',c)}}var g=e.fn.animate;e.fn.animate=function(a){if('background-position'in a){a.backgroundPosition=a['background-position'];delete a['background-position']}if('backgroundPosition'in a){a.backgroundPosition='('+a.backgroundPosition}return g.apply(this,arguments)};function toArray(a){a=a.replace(/left|top/g,'0px');a=a.replace(/right|bottom/g,'100%');a=a.replace(/([0-9\.]+)(\s|\)|$)/g,"$1px$2");var b=a.match(/(-?[0-9\.]+)(px|\%|em|pt)\s(-?[0-9\.]+)(px|\%|em|pt)/);return[parseFloat(b[1],10),b[2],parseFloat(b[3],10),b[4]]}e.fx.step.backgroundPosition=function(a){if(!a.bgPosReady){var b=e.curCSS(a.elem,'backgroundPosition');if(!b){b='0px 0px'}b=toArray(b);a.start=[b[0],b[2]];var c=toArray(a.options.curAnim.backgroundPosition);a.end=[c[0],c[2]];a.unit=[c[1],c[3]];a.bgPosReady=true}var d=[];d[0]=((a.end[0]-a.start[0])*a.pos)+a.start[0]+a.unit[0];d[1]=((a.end[1]-a.start[1])*a.pos)+a.start[1]+a.unit[1];a.elem.style.backgroundPosition=d[0]+' '+d[1]}})(jQuery);
(function(jQuery) {
	jQuery.extend(jQuery.fx.step,{
	    backgroundPosition: function(fx) {
            if (fx.state === 0 && typeof fx.end == 'string') {
                var start = jQuery.curCSS(fx.elem,'backgroundPosition');
                start = toArray(start);
                fx.start = [start[0],start[2]];
                var end = toArray(fx.end);
                fx.end = [end[0],end[2]];
                fx.unit = [end[1],end[3]];
			}
            var nowPosX = [];
            nowPosX[0] = ((fx.end[0] - fx.start[0]) * fx.pos) + fx.start[0] + fx.unit[0];
            nowPosX[1] = ((fx.end[1] - fx.start[1]) * fx.pos) + fx.start[1] + fx.unit[1];
            fx.elem.style.backgroundPosition = nowPosX[0]+' '+nowPosX[1];

           function toArray(strg){
               strg = strg.replace(/left|top/g,'0px');
               strg = strg.replace(/right|bottom/g,'100%');
               strg = strg.replace(/([0-9\.]+)(\s|\)|$)/g,"$1px$2");
               var res = strg.match(/(-?[0-9\.]+)(px|\%|em|pt)\s(-?[0-9\.]+)(px|\%|em|pt)/);
               return [parseFloat(res[1],10),res[2],parseFloat(res[3],10),res[4]];
           }
        }
	});
})(jQuery);


/* Uniform */
//(function(a){a.uniform={options:{selectClass:"selector",radioClass:"radio",checkboxClass:"checker",fileClass:"uploader",filenameClass:"filename",fileBtnClass:"action",fileDefaultText:"No file selected",fileBtnText:"Choose File",checkedClass:"checked",focusClass:"focus",disabledClass:"disabled",buttonClass:"button",activeClass:"active",hoverClass:"hover",useID:true,idPrefix:"uniform",resetSelector:false,autoHide:true},elements:[]};if(a.browser.msie&&a.browser.version<7){a.support.selectOpacity=false}else{a.support.selectOpacity=true}a.fn.uniform=function(k){k=a.extend(a.uniform.options,k);var d=this;if(k.resetSelector!=false){a(k.resetSelector).mouseup(function(){function l(){a.uniform.update(d)}setTimeout(l,10)})}function j(l){$el=a(l);$el.addClass($el.attr("type"));b(l)}function g(l){a(l).addClass("uniform");b(l)}function i(o){var m=a(o);var p=a("<div>"),l=a("<span>");p.addClass(k.buttonClass);if(k.useID&&m.attr("id")!=""){p.attr("id",k.idPrefix+"-"+m.attr("id"))}var n;if(m.is("a")||m.is("button")){n=m.text()}else{if(m.is(":submit")||m.is(":reset")||m.is("input[type=button]")){n=m.attr("value")}}n=n==""?m.is(":reset")?"Reset":"Submit":n;l.html(n);m.css("opacity",0);m.wrap(p);m.wrap(l);p=m.closest("div");l=m.closest("span");if(m.is(":disabled")){p.addClass(k.disabledClass)}p.bind({"mouseenter.uniform":function(){p.addClass(k.hoverClass)},"mouseleave.uniform":function(){p.removeClass(k.hoverClass);p.removeClass(k.activeClass)},"mousedown.uniform touchbegin.uniform":function(){p.addClass(k.activeClass)},"mouseup.uniform touchend.uniform":function(){p.removeClass(k.activeClass)},"click.uniform touchend.uniform":function(r){if(a(r.target).is("span")||a(r.target).is("div")){if(o[0].dispatchEvent){var q=document.createEvent("MouseEvents");q.initEvent("click",true,true);o[0].dispatchEvent(q)}else{o[0].click()}}}});o.bind({"focus.uniform":function(){p.addClass(k.focusClass)},"blur.uniform":function(){p.removeClass(k.focusClass)}});a.uniform.noSelect(p);b(o)}function e(o){var m=a(o);var p=a("<div />"),l=a("<span />");if(!m.css("display")=="none"&&k.autoHide){p.hide()}p.addClass(k.selectClass);if(k.useID&&o.attr("id")!=""){p.attr("id",k.idPrefix+"-"+o.attr("id"))}var n=o.find(":selected:first");if(n.length==0){n=o.find("option:first")}l.html(n.html());o.css("opacity",0);o.wrap(p);o.before(l);p=o.parent("div");l=o.siblings("span");o.bind({"change.uniform":function(){l.text(o.find(":selected").html());p.removeClass(k.activeClass)},"focus.uniform":function(){p.addClass(k.focusClass)},"blur.uniform":function(){p.removeClass(k.focusClass);p.removeClass(k.activeClass)},"mousedown.uniform touchbegin.uniform":function(){p.addClass(k.activeClass)},"mouseup.uniform touchend.uniform":function(){p.removeClass(k.activeClass)},"click.uniform touchend.uniform":function(){p.removeClass(k.activeClass)},"mouseenter.uniform":function(){p.addClass(k.hoverClass)},"mouseleave.uniform":function(){p.removeClass(k.hoverClass);p.removeClass(k.activeClass)},"keyup.uniform":function(){l.text(o.find(":selected").html())}});if(a(o).attr("disabled")){p.addClass(k.disabledClass)}a.uniform.noSelect(l);b(o)}function f(n){var m=a(n);var o=a("<div />"),l=a("<span />");if(!m.css("display")=="none"&&k.autoHide){o.hide()}o.addClass(k.checkboxClass);if(k.useID&&n.attr("id")!=""){o.attr("id",k.idPrefix+"-"+n.attr("id"))}a(n).wrap(o);a(n).wrap(l);l=n.parent();o=l.parent();a(n).css("opacity",0).bind({"focus.uniform":function(){o.addClass(k.focusClass)},"blur.uniform":function(){o.removeClass(k.focusClass)},"click.uniform touchend.uniform":function(){if(!a(n).attr("checked")){l.removeClass(k.checkedClass)}else{l.addClass(k.checkedClass)}},"mousedown.uniform touchbegin.uniform":function(){o.addClass(k.activeClass)},"mouseup.uniform touchend.uniform":function(){o.removeClass(k.activeClass)},"mouseenter.uniform":function(){o.addClass(k.hoverClass)},"mouseleave.uniform":function(){o.removeClass(k.hoverClass);o.removeClass(k.activeClass)}});if(a(n).attr("checked")){l.addClass(k.checkedClass)}if(a(n).attr("disabled")){o.addClass(k.disabledClass)}b(n)}function c(n){var m=a(n);var o=a("<div />"),l=a("<span />");if(!m.css("display")=="none"&&k.autoHide){o.hide()}o.addClass(k.radioClass);if(k.useID&&n.attr("id")!=""){o.attr("id",k.idPrefix+"-"+n.attr("id"))}a(n).wrap(o);a(n).wrap(l);l=n.parent();o=l.parent();a(n).css("opacity",0).bind({"focus.uniform":function(){o.addClass(k.focusClass)},"blur.uniform":function(){o.removeClass(k.focusClass)},"click.uniform touchend.uniform":function(){if(!a(n).attr("checked")){l.removeClass(k.checkedClass)}else{var p=k.radioClass.split(" ")[0];a("."+p+" span."+k.checkedClass+":has([name='"+a(n).attr("name")+"'])").removeClass(k.checkedClass);l.addClass(k.checkedClass)}},"mousedown.uniform touchend.uniform":function(){if(!a(n).is(":disabled")){o.addClass(k.activeClass)}},"mouseup.uniform touchbegin.uniform":function(){o.removeClass(k.activeClass)},"mouseenter.uniform touchend.uniform":function(){o.addClass(k.hoverClass)},"mouseleave.uniform":function(){o.removeClass(k.hoverClass);o.removeClass(k.activeClass)}});if(a(n).attr("checked")){l.addClass(k.checkedClass)}if(a(n).attr("disabled")){o.addClass(k.disabledClass)}b(n)}function h(q){var o=a(q);var r=a("<div />"),p=a("<span>"+k.fileDefaultText+"</span>"),m=a("<span>"+k.fileBtnText+"</span>");if(!o.css("display")=="none"&&k.autoHide){r.hide()}r.addClass(k.fileClass);p.addClass(k.filenameClass);m.addClass(k.fileBtnClass);if(k.useID&&o.attr("id")!=""){r.attr("id",k.idPrefix+"-"+o.attr("id"))}o.wrap(r);o.after(m);o.after(p);r=o.closest("div");p=o.siblings("."+k.filenameClass);m=o.siblings("."+k.fileBtnClass);if(!o.attr("size")){var l=r.width();o.attr("size",l/10)}var n=function(){var s=o.val();if(s===""){s=k.fileDefaultText}else{s=s.split(/[\/\\]+/);s=s[(s.length-1)]}p.text(s)};n();o.css("opacity",0).bind({"focus.uniform":function(){r.addClass(k.focusClass)},"blur.uniform":function(){r.removeClass(k.focusClass)},"mousedown.uniform":function(){if(!a(q).is(":disabled")){r.addClass(k.activeClass)}},"mouseup.uniform":function(){r.removeClass(k.activeClass)},"mouseenter.uniform":function(){r.addClass(k.hoverClass)},"mouseleave.uniform":function(){r.removeClass(k.hoverClass);r.removeClass(k.activeClass)}});if(a.browser.msie){o.bind("click.uniform.ie7",function(){setTimeout(n,0)})}else{o.bind("change.uniform",n)}if(o.attr("disabled")){r.addClass(k.disabledClass)}a.uniform.noSelect(p);a.uniform.noSelect(m);b(q)}a.uniform.restore=function(l){if(l==undefined){l=a(a.uniform.elements)}a(l).each(function(){if(a(this).is(":checkbox")){a(this).unwrap().unwrap()}else{if(a(this).is("select")){a(this).siblings("span").remove();a(this).unwrap()}else{if(a(this).is(":radio")){a(this).unwrap().unwrap()}else{if(a(this).is(":file")){a(this).siblings("span").remove();a(this).unwrap()}else{if(a(this).is("button, :submit, :reset, a, input[type='button']")){a(this).unwrap().unwrap()}}}}}a(this).unbind(".uniform");a(this).css("opacity","1");var m=a.inArray(a(l),a.uniform.elements);a.uniform.elements.splice(m,1)})};function b(l){l=a(l).get();if(l.length>1){a.each(l,function(m,n){a.uniform.elements.push(n)})}else{a.uniform.elements.push(l)}}a.uniform.noSelect=function(l){function m(){return false}a(l).each(function(){this.onselectstart=this.ondragstart=m;a(this).mousedown(m).css({MozUserSelect:"none"})})};a.uniform.update=function(l){if(l==undefined){l=a(a.uniform.elements)}l=a(l);l.each(function(){var n=a(this);if(n.is("select")){var m=n.siblings("span");var p=n.parent("div");p.removeClass(k.hoverClass+" "+k.focusClass+" "+k.activeClass);m.html(n.find(":selected").html());if(n.is(":disabled")){p.addClass(k.disabledClass)}else{p.removeClass(k.disabledClass)}}else{if(n.is(":checkbox")){var m=n.closest("span");var p=n.closest("div");p.removeClass(k.hoverClass+" "+k.focusClass+" "+k.activeClass);m.removeClass(k.checkedClass);if(n.is(":checked")){m.addClass(k.checkedClass)}if(n.is(":disabled")){p.addClass(k.disabledClass)}else{p.removeClass(k.disabledClass)}}else{if(n.is(":radio")){var m=n.closest("span");var p=n.closest("div");p.removeClass(k.hoverClass+" "+k.focusClass+" "+k.activeClass);m.removeClass(k.checkedClass);if(n.is(":checked")){m.addClass(k.checkedClass)}if(n.is(":disabled")){p.addClass(k.disabledClass)}else{p.removeClass(k.disabledClass)}}else{if(n.is(":file")){var p=n.parent("div");var o=n.siblings(k.filenameClass);btnTag=n.siblings(k.fileBtnClass);p.removeClass(k.hoverClass+" "+k.focusClass+" "+k.activeClass);o.text(n.val());if(n.is(":disabled")){p.addClass(k.disabledClass)}else{p.removeClass(k.disabledClass)}}else{if(n.is(":submit")||n.is(":reset")||n.is("button")||n.is("a")||l.is("input[type=button]")){var p=n.closest("div");p.removeClass(k.hoverClass+" "+k.focusClass+" "+k.activeClass);if(n.is(":disabled")){p.addClass(k.disabledClass)}else{p.removeClass(k.disabledClass)}}}}}}})};return this.each(function(){if(a.support.selectOpacity){var l=a(this);if(l.is("select")){if(l.attr("multiple")!=true){if(l.attr("size")==undefined||l.attr("size")<=1){e(l)}}}else{if(l.is(":checkbox")){f(l)}else{if(l.is(":radio")){c(l)}else{if(l.is(":file")){h(l)}else{if(l.is(":text, :password, input[type='email']")){j(l)}else{if(l.is("textarea")){g(l)}else{if(l.is("a")||l.is(":submit")||l.is(":reset")||l.is("button")||l.is("input[type=button]")){i(l)}}}}}}}}})}})(jQuery);

/**
 * Color picker
 * Author: Stefan Petre www.eyecon.ro
 * Dual licensed under the MIT and GPL licenses
 */
(function(j){var k=function(){var g={},inAction,charMin=65,visible,tpl='<div class="colorpicker"><div class="colorpicker_color"><div><div></div></div></div><div class="colorpicker_hue"><div></div></div><div class="colorpicker_new_color"></div><div class="colorpicker_current_color"></div><div class="colorpicker_hex"><input type="text" maxlength="6" size="6" /></div><div class="colorpicker_rgb_r colorpicker_field"><input type="text" maxlength="3" size="3" /><span></span></div><div class="colorpicker_rgb_g colorpicker_field"><input type="text" maxlength="3" size="3" /><span></span></div><div class="colorpicker_rgb_b colorpicker_field"><input type="text" maxlength="3" size="3" /><span></span></div><div class="colorpicker_hsb_h colorpicker_field"><input type="text" maxlength="3" size="3" /><span></span></div><div class="colorpicker_hsb_s colorpicker_field"><input type="text" maxlength="3" size="3" /><span></span></div><div class="colorpicker_hsb_b colorpicker_field"><input type="text" maxlength="3" size="3" /><span></span></div><div class="colorpicker_submit"></div></div>',defaults={eventName:'click',onShow:function(){},onBeforeShow:function(){},onHide:function(){},onChange:function(){},onSubmit:function(){},color:'ff0000',livePreview:true,flat:false},fillRGBFields=function(a,b){var c=HSBToRGB(a);j(b).data('colorpicker').fields.eq(1).val(c.r).end().eq(2).val(c.g).end().eq(3).val(c.b).end()},fillHSBFields=function(a,b){j(b).data('colorpicker').fields.eq(4).val(a.h).end().eq(5).val(a.s).end().eq(6).val(a.b).end()},fillHexFields=function(a,b){j(b).data('colorpicker').fields.eq(0).val(HSBToHex(a)).end()},setSelector=function(a,b){j(b).data('colorpicker').selector.css('backgroundColor','#'+HSBToHex({h:a.h,s:100,b:100}));j(b).data('colorpicker').selectorIndic.css({left:parseInt(150*a.s/100,10),top:parseInt(150*(100-a.b)/100,10)})},setHue=function(a,b){j(b).data('colorpicker').hue.css('top',parseInt(150-150*a.h/360,10))},setCurrentColor=function(a,b){j(b).data('colorpicker').currentColor.css('backgroundColor','#'+HSBToHex(a))},setNewColor=function(a,b){j(b).data('colorpicker').newColor.css('backgroundColor','#'+HSBToHex(a))},keyDown=function(a){var b=a.charCode||a.keyCode||-1;if((b>charMin&&b<=90)||b==32){return false}var c=j(this).parent().parent();if(c.data('colorpicker').livePreview===true){change.apply(this)}},change=function(a){var b=j(this).parent().parent(),col;if(this.parentNode.className.indexOf('_hex')>0){b.data('colorpicker').color=col=HexToHSB(fixHex(this.value))}else if(this.parentNode.className.indexOf('_hsb')>0){b.data('colorpicker').color=col=fixHSB({h:parseInt(b.data('colorpicker').fields.eq(4).val(),10),s:parseInt(b.data('colorpicker').fields.eq(5).val(),10),b:parseInt(b.data('colorpicker').fields.eq(6).val(),10)})}else{b.data('colorpicker').color=col=RGBToHSB(fixRGB({r:parseInt(b.data('colorpicker').fields.eq(1).val(),10),g:parseInt(b.data('colorpicker').fields.eq(2).val(),10),b:parseInt(b.data('colorpicker').fields.eq(3).val(),10)}))}if(a){fillRGBFields(col,b.get(0));fillHexFields(col,b.get(0));fillHSBFields(col,b.get(0))}setSelector(col,b.get(0));setHue(col,b.get(0));setNewColor(col,b.get(0));b.data('colorpicker').onChange.apply(b,[col,HSBToHex(col),HSBToRGB(col)])},blur=function(a){var b=j(this).parent().parent();b.data('colorpicker').fields.parent().removeClass('colorpicker_focus')},focus=function(){charMin=this.parentNode.className.indexOf('_hex')>0?70:65;j(this).parent().parent().data('colorpicker').fields.parent().removeClass('colorpicker_focus');j(this).parent().addClass('colorpicker_focus')},downIncrement=function(a){var b=j(this).parent().find('input').focus();var c={el:j(this).parent().addClass('colorpicker_slider'),max:this.parentNode.className.indexOf('_hsb_h')>0?360:(this.parentNode.className.indexOf('_hsb')>0?100:255),y:a.pageY,field:b,val:parseInt(b.val(),10),preview:j(this).parent().parent().data('colorpicker').livePreview};j(document).bind('mouseup',c,upIncrement);j(document).bind('mousemove',c,moveIncrement)},moveIncrement=function(a){a.data.field.val(Math.max(0,Math.min(a.data.max,parseInt(a.data.val+a.pageY-a.data.y,10))));if(a.data.preview){change.apply(a.data.field.get(0),[true])}return false},upIncrement=function(a){change.apply(a.data.field.get(0),[true]);a.data.el.removeClass('colorpicker_slider').find('input').focus();j(document).unbind('mouseup',upIncrement);j(document).unbind('mousemove',moveIncrement);return false},downHue=function(a){var b={cal:j(this).parent(),y:j(this).offset().top};b.preview=b.cal.data('colorpicker').livePreview;j(document).bind('mouseup',b,upHue);j(document).bind('mousemove',b,moveHue)},moveHue=function(a){change.apply(a.data.cal.data('colorpicker').fields.eq(4).val(parseInt(360*(150-Math.max(0,Math.min(150,(a.pageY-a.data.y))))/150,10)).get(0),[a.data.preview]);return false},upHue=function(a){fillRGBFields(a.data.cal.data('colorpicker').color,a.data.cal.get(0));fillHexFields(a.data.cal.data('colorpicker').color,a.data.cal.get(0));j(document).unbind('mouseup',upHue);j(document).unbind('mousemove',moveHue);return false},downSelector=function(a){var b={cal:j(this).parent(),pos:j(this).offset()};b.preview=b.cal.data('colorpicker').livePreview;j(document).bind('mouseup',b,upSelector);j(document).bind('mousemove',b,moveSelector)},moveSelector=function(a){change.apply(a.data.cal.data('colorpicker').fields.eq(6).val(parseInt(100*(150-Math.max(0,Math.min(150,(a.pageY-a.data.pos.top))))/150,10)).end().eq(5).val(parseInt(100*(Math.max(0,Math.min(150,(a.pageX-a.data.pos.left))))/150,10)).get(0),[a.data.preview]);return false},upSelector=function(a){fillRGBFields(a.data.cal.data('colorpicker').color,a.data.cal.get(0));fillHexFields(a.data.cal.data('colorpicker').color,a.data.cal.get(0));j(document).unbind('mouseup',upSelector);j(document).unbind('mousemove',moveSelector);return false},enterSubmit=function(a){j(this).addClass('colorpicker_focus')},leaveSubmit=function(a){j(this).removeClass('colorpicker_focus')},clickSubmit=function(a){var b=j(this).parent();var c=b.data('colorpicker').color;b.data('colorpicker').origColor=c;setCurrentColor(c,b.get(0));b.data('colorpicker').onSubmit(c,HSBToHex(c),HSBToRGB(c),b.data('colorpicker').el)},show=function(a){var b=j('#'+j(this).data('colorpickerId'));b.data('colorpicker').onBeforeShow.apply(this,[b.get(0)]);var c=j(this).offset();var d=getViewport();var e=c.top+this.offsetHeight;var f=c.left;if(e+176>d.t+d.h){e-=this.offsetHeight+176}if(f+356>d.l+d.w){f-=356}b.css({left:f+'px',top:e+'px'});if(b.data('colorpicker').onShow.apply(this,[b.get(0)])!=false){b.show()}j(document).bind('mousedown',{cal:b},hide);j(b).find('.colorpicker_submit').bind('mousedown',{cal:b},hide);return false},hide=function(a){if(!isChildOf(a.data.cal.get(0),a.target,a.data.cal.get(0))){if(a.data.cal.data('colorpicker').onHide.apply(this,[a.data.cal.get(0)])!=false){a.data.cal.hide()}j(document).unbind('mousedown',hide)}},isChildOf=function(a,b,c){if(a==b){return true}if(a.contains){return a.contains(b)}if(a.compareDocumentPosition){return!!(a.compareDocumentPosition(b)&16)}var d=b.parentNode;while(d&&d!=c){if(d==a)return true;d=d.parentNode}return false},getViewport=function(){var m=document.compatMode=='CSS1Compat';return{l:window.pageXOffset||(m?document.documentElement.scrollLeft:document.body.scrollLeft),t:window.pageYOffset||(m?document.documentElement.scrollTop:document.body.scrollTop),w:window.innerWidth||(m?document.documentElement.clientWidth:document.body.clientWidth),h:window.innerHeight||(m?document.documentElement.clientHeight:document.body.clientHeight)}},fixHSB=function(a){return{h:Math.min(360,Math.max(0,a.h)),s:Math.min(100,Math.max(0,a.s)),b:Math.min(100,Math.max(0,a.b))}},fixRGB=function(a){return{r:Math.min(255,Math.max(0,a.r)),g:Math.min(255,Math.max(0,a.g)),b:Math.min(255,Math.max(0,a.b))}},fixHex=function(a){var b=6-a.length;if(b>0){var o=[];for(var i=0;i<b;i++){o.push('0')}o.push(a);a=o.join('')}return a},HexToRGB=function(a){var a=parseInt(((a.indexOf('#')>-1)?a.substring(1):a),16);return{r:a>>16,g:(a&0x00FF00)>>8,b:(a&0x0000FF)}},HexToHSB=function(a){return RGBToHSB(HexToRGB(a))},RGBToHSB=function(a){var b={h:0,s:0,b:0};var c=Math.min(a.r,a.g,a.b);var d=Math.max(a.r,a.g,a.b);var e=d-c;b.b=d;if(d!=0){}b.s=d!=0?255*e/d:0;if(b.s!=0){if(a.r==d){b.h=(a.g-a.b)/e}else if(a.g==d){b.h=2+(a.b-a.r)/e}else{b.h=4+(a.r-a.g)/e}}else{b.h=-1}b.h*=60;if(b.h<0){b.h+=360}b.s*=100/255;b.b*=100/255;return b},HSBToRGB=function(a){var b={};var h=Math.round(a.h);var s=Math.round(a.s*255/100);var v=Math.round(a.b*255/100);if(s==0){b.r=b.g=b.b=v}else{var c=v;var d=(255-s)*v/255;var e=(c-d)*(h%60)/60;if(h==360)h=0;if(h<60){b.r=c;b.b=d;b.g=d+e}else if(h<120){b.g=c;b.b=d;b.r=c-e}else if(h<180){b.g=c;b.r=d;b.b=d+e}else if(h<240){b.b=c;b.r=d;b.g=c-e}else if(h<300){b.b=c;b.g=d;b.r=d+e}else if(h<360){b.r=c;b.g=d;b.b=c-e}else{b.r=0;b.g=0;b.b=0}}return{r:Math.round(b.r),g:Math.round(b.g),b:Math.round(b.b)}},RGBToHex=function(c){var d=[c.r.toString(16),c.g.toString(16),c.b.toString(16)];j.each(d,function(a,b){if(b.length==1){d[a]='0'+b}});return d.join('')},HSBToHex=function(a){return RGBToHex(HSBToRGB(a))},restoreOriginal=function(){var a=j(this).parent();var b=a.data('colorpicker').origColor;a.data('colorpicker').color=b;fillRGBFields(b,a.get(0));fillHexFields(b,a.get(0));fillHSBFields(b,a.get(0));setSelector(b,a.get(0));setHue(b,a.get(0));setNewColor(b,a.get(0))};return{init:function(d){d=j.extend({},defaults,d||{});if(typeof d.color=='string'){d.color=HexToHSB(d.color)}else if(d.color.r!=undefined&&d.color.g!=undefined&&d.color.b!=undefined){d.color=RGBToHSB(d.color)}else if(d.color.h!=undefined&&d.color.s!=undefined&&d.color.b!=undefined){d.color=fixHSB(d.color)}else{return this}return this.each(function(){if(!j(this).data('colorpickerId')){var a=j.extend({},d);a.origColor=d.color;var b='collorpicker_'+parseInt(Math.random()*1000);j(this).data('colorpickerId',b);var c=j(tpl).attr('id',b);if(a.flat){c.appendTo(this).show()}else{c.appendTo(document.body)}a.fields=c.find('input').bind('keyup',keyDown).bind('change',change).bind('blur',blur).bind('focus',focus);c.find('span').bind('mousedown',downIncrement).end().find('>div.colorpicker_current_color').bind('click',restoreOriginal);a.selector=c.find('div.colorpicker_color').bind('mousedown',downSelector);a.selectorIndic=a.selector.find('div div');a.el=this;a.hue=c.find('div.colorpicker_hue div');c.find('div.colorpicker_hue').bind('mousedown',downHue);a.newColor=c.find('div.colorpicker_new_color');a.currentColor=c.find('div.colorpicker_current_color');c.data('colorpicker',a);c.find('div.colorpicker_submit').bind('mouseenter',enterSubmit).bind('mouseleave',leaveSubmit).bind('click',clickSubmit);fillRGBFields(a.color,c.get(0));fillHSBFields(a.color,c.get(0));fillHexFields(a.color,c.get(0));setHue(a.color,c.get(0));setSelector(a.color,c.get(0));setCurrentColor(a.color,c.get(0));setNewColor(a.color,c.get(0));if(a.flat){c.css({position:'relative',display:'block'})}else{j(this).bind(a.eventName,show)}}})},showPicker:function(){return this.each(function(){if(j(this).data('colorpickerId')){show.apply(this)}})},hidePicker:function(){return this.each(function(){if(j(this).data('colorpickerId')){j('#'+j(this).data('colorpickerId')).fadeOut(500)}})},setColor:function(b){if(typeof b=='string'){b=HexToHSB(b)}else if(b.r!=undefined&&b.g!=undefined&&b.b!=undefined){b=RGBToHSB(b)}else if(b.h!=undefined&&b.s!=undefined&&b.b!=undefined){b=fixHSB(b)}else{return this}return this.each(function(){if(j(this).data('colorpickerId')){var a=j('#'+j(this).data('colorpickerId'));a.data('colorpicker').color=b;a.data('colorpicker').origColor=b;fillRGBFields(b,a.get(0));fillHSBFields(b,a.get(0));fillHexFields(b,a.get(0));setHue(b,a.get(0));setSelector(b,a.get(0));setCurrentColor(b,a.get(0));setNewColor(b,a.get(0))}})}}}();j.fn.extend({ColorPicker:k.init,ColorPickerHide:k.hidePicker,ColorPickerShow:k.showPicker,ColorPickerSetColor:k.setColor})})(jQuery);

/*
 * Vertex vertexToggle jQuery
 */
//eval(function(p,a,c,k,e,r){e=function(c){return(c<a?'':e(parseInt(c/a)))+((c=c%a)>35?String.fromCharCode(c+29):c.toString(36))};if(!''.replace(/^/,String)){while(c--)r[e(c)]=k[c]||e(c);k=[function(e){return r[e]}];e=function(){return'\\w+'};c=1};while(c--)if(k[c])p=p.replace(new RegExp('\\b'+e(c)+'\\b','g'),k[c]);return p}('(4(g){g.Q.o=4(d){j=7;p f={q:\'R\',u:7,v:\'S\',w:T,B:4(){},C:4(){},D:4(){},x:4(){}},2=g.U({},f,d);3.E(4(){p b=g(3);5(b.8(\'V\')==\'W\'){p c=b.8(\'F\');1(2.u,c);b.6(\'G\').H(\'<1 I="o" i="\'+c+\'"></1>\');5(b.8(\'l\')){b.m(\'1\').6(\'k\')}9{b.m(\'1\').6(\'r\')}}9{b.X(\'y:\'+2.q).E(4(){p a=g(3).8(\'F\');1(2.u,a);g(3).6(\'G\').H(\'<1 I="o" i="\'+a+\'"></1>\');5(g(3).8(\'l\')){g(3).m(\'1\').6(\'k\')}9{g(3).m(\'1\').6(\'r\')}5(2.q==\'J\'){g(3).m(\'1\').6(\'K\')}})}});4 1(e,a){5(e==7){5(2.q==\'J\'){g(\'1[i=\'+a+\']\').6(\'Y\')}9{g(\'1[i=\'+a+\']\').6(\'Z\')}}9{g(\'1[i=\'+a+\']\').10()}}g(\'1.o\').11(4(){5(j==7){j=L;5(g(3).z(\'K\')){5(g(3).z(\'k\')){j=7}9{s(g(3),7)}}9{s(g(3))}}12 L});4 s(a,b){2.B.n(a);h=a.13();t=a.8(\'i\');5(a.z(\'k\')){2.D.n(a);a.M({N:\'A% A%\'},2.w,2.v,4(){a.O(\'k\').6(\'r\');j=7;2.x.n(3)});g(\'y#\'+t).14(\'l\')}9{2.C.n(a);a.M({N:\'0% A%\'},2.w,2.v,4(){a.O(\'r\').6(\'k\');j=7;2.x.n(3)});g(\'y#\'+t).8(\'l\',\'l\')}5(b==7){P=g(\'#\'+t).8(\'P\');s(a.15(\'1[i]\'))}}}})(16);',62,69,'|label|settings|this|function|if|addClass|true|attr|else|||||||||for|clickEnabled|vertexOn|checked|prev|call|vertexToggle|var|type|vertexOff|slide||keepLabel|easing|speed|onSlide|input|hasClass|100|onClick|onClickOn|onClickOff|each|id|vertex_checkbox|before|class|radio|vertex_radio|false|animate|backgroundPosition|removeClass|name|fn|checkbox|easeOutExpo|200|extend|tagName|INPUT|children|vertex_label_radio|vertex_label|remove|click|return|innerHeight|removeAttr|siblings|jQuery'.split('|'),0,{}));
(function (g) {
  g.fn.vertexToggle = function (d) {
    var f = {
      type: 'checkbox',
      keepLabel: true,
      easing: 'easeOutExpo',
      speed: 200,
      onClick: function () {},
      onClickOn: function () {},
      onClickOff: function () {},
      onSlide: function () {}
    }, settings = g.extend({}, f, d);
    this.each(function () {
      var b = g(this);
      //console.log(this, b);
      if(b.prop('tagName') == 'INPUT') {
        var c = b.prop('id');
        var l = jQuery('<label />').prop('for', c).addClass('vertexToggle');
        b.before(l);
        l.click(function() {
          console.log('click');
          slide(g(this));
          return false
        });
        if(b.prop('checked')) {
          b.prev('label').addClass('vertexOn');
        } else {
          b.prev('label').addClass('vertexOff');
        }
      } else {
        b.children('input:' + settings.type).each(function () {
          var a = g(this).prop('id');
          g(this).before('<label class="vertexToggle" for="' + a + '"></label>');
          if(g(this).prop('checked')) {
            g(this).prev('label').addClass('vertexOn');
          } else {
            g(this).prev('label').addClass('vertexOff');
          }
        });
      }
    });
    function slide(a) {
      console.log('slide');
      settings.onClick.call(a);
      var t = a.attr('for');
      if(a.hasClass('vertexOn')) {
        settings.onClickOff.call(a);
        a.removeClass('vertexOn').addClass('vertexOff');
        settings.onSlide.call(this);
        g('input#' + t).prop('checked', null);
      } else {
        settings.onClickOn.call(a);
        a.removeClass('vertexOff').addClass('vertexOn');
        settings.onSlide.call(this);
        g('input#' + t).prop('checked', 'checked');
      }
    }
  }
})(jQuery);


/**
 * port of coolMultiple jQuery plugin
 * Transforms a select or a list of checkboxes into a nicer control.+
 * Tested with jQuery 1.5.2
 * @version 1.3
 * @author vlad fratila, vlad.fratila@gmail.com
 */
//eval(function(p,a,c,k,e,r){e=function(c){return(c<a?'':e(parseInt(c/a)))+((c=c%a)>35?String.fromCharCode(c+29):c.toString(36))};if(!''.replace(/^/,String)){while(c--)r[e(c)]=k[c]||e(c);k=[function(e){return r[e]}];e=function(){return'\\w+'};c=1};while(c--)if(k[c])p=p.replace(new RegExp('\\b'+e(c)+'\\b','g'),k[c]);return p}('(9(e){5 f={\'G\':9(a){5 d=X Y();3.2={H:\'Z\',g:\'h\',s:\'10 11 a 12\',7:\'13\'+(d.14())};4(a){3.2=e.15(3.2,a)}5 b=3;b.I();b.C=b.x().r(\'<6 l="\'+b.2.7+\'" v="i"></6>\').8(\'6#\'+b.2.7);b.6=b.C.r(\'<6 l="\'+b.2.7+\'J" v="i-16"></6>\').8(\'6#\'+b.2.7+\'J\');b.m=b.C.r(\'<6 l="\'+b.2.7+\'K" 17="18:19;" v="i-m"></6>\').8(\'6#\'+b.2.7+\'K\');4(3.2.s!=\'\')b.m.r(\'<6 v="i-s">\'+3.2.s+\'</6>\');4(3.2.g==\'h\'){3.j(\'L\')}k 4(3.2.g==\'w\'){3.j(\'M\')}},\'L\':9(){5 b=3;b.8(\'D\').N(9(){b.6.r(\'<p l="\'+b.2.7+\'t\'+e(3).y()+\'">\'+e(3).u()+\'</p>\');4(e(3).n(\'q\')){b.j(\'h\',e(3).y())}});b.6.8(\'p\').E(9(){5 a=e(3).n(\'l\').O(b.2.7+\'t\',\'\');4(!e(3).P(\'i-q\')){b.j(\'h\',a)}k{b.j(\'z\',a)}})},\'M\':9(){5 b=3;b.8(\'F[1a="1b"]\').N(9(){b.6.r(\'<p l="\'+b.2.7+\'t\'+e(3).y()+\'">\'+e(3).x().u()+\'</p>\');4(e(3).n(\'A\')){b.j(\'h\',e(3).y())}});b.6.8(\'p\').E(9(){5 a=e(3).n(\'l\').O(b.2.7+\'t\',\'\');4(!e(3).P(\'i-q\')){b.j(\'h\',a)}k{b.j(\'z\',a)}})},\'h\':9(o){5 a=3;4(a.2.g==\'h\'){5 b=\'D\'}k 4(a.2.g==\'w\'){5 b=\'F\'}5 c=a.8(b+\'[Q="\'+o+\'"]\');4(a.2.g==\'h\'){c.n(\'q\',\'q\');5 d=c.u()}k 4(a.2.g==\'w\'){5 d=c.x().u();c.n(\'A\',\'A\')}e(\'p#\'+a.2.7+\'t\'+o).1c(\'i-q\');a.m.r(\'<p l="\'+a.2.7+\'R\'+o+\'">\'+d+\'<a v="i-1d" 1e="#">\'+a.2.H+\'</a></p>\').8(\'a\').E(9(){a.j(\'z\',o);B 1f});a.m.8(\'.i-s\').I()},\'z\':9(o){5 a=3;4(a.2.g==\'h\'){5 b=\'D\'}k 4(a.2.g==\'w\'){5 b=\'F\'}5 c=a.8(b+\'[Q="\'+o+\'"]\');4(a.2.g==\'h\'){c.n(\'q\',\'\');5 d=c.u()}k 4(a.2.g==\'w\'){5 d=c.x().u();c.n(\'A\',\'\')}e(\'p#\'+a.2.7+\'t\'+o).1g(\'i-q\');a.m.8(\'p#\'+a.2.7+\'R\'+o).1h();4(a.m.8(\'p\').1i==0)a.m.8(\'.i-s\').1j()}};e.1k.j=9(a){4(f[a]){B f[a].S(3,1l.1m.1n.1o(T,1))}k 4(1p a===\'1q\'||!a){B f.G.S(3,T)}k{4(U.V)U.V(\'1r \'+a+\' 1s 1t 1u 1v W.j\')}B 3}})(W);',62,94,'||settings|this|if|var|div|_id|find|function|||||||mode|select|multis|coolMultiple|else|id|values|attr|||selected|append|infotext|_o_|text|class|checkboxes|parent|val|deselect|checked|return|wrapper|option|click|input|init|delText|hide|_scrollbox|_values|init_select|init_checkboxes|each|replace|hasClass|value|_os_|apply|arguments|console|log|jQuery|new|Date|Remove|Please|make|selection|multis_|getTime|extend|scrollbox|style|display|none|type|checkbox|addClass|del|href|false|removeClass|remove|length|show|fn|Array|prototype|slice|call|typeof|object|Method|does|not|exist|on'.split('|'),0,{}))
(function(e){var f={'init':function(a){var d=new Date();this.settings={delText:'Remove',mode:'select',infotext:'Please make a selection',_id:'multis_'+(d.getTime())};if(a){this.settings=e.extend(this.settings,a)}var b=this;b.hide();b.wrapper=b.parent().append('<div id="'+b.settings._id+'" class="multis"></div>').find('div#'+b.settings._id);b.div=b.wrapper.append('<div id="'+b.settings._id+'_scrollbox" class="multis-scrollbox"></div>').find('div#'+b.settings._id+'_scrollbox');b.values=b.wrapper.append('<div id="'+b.settings._id+'_values" style="display:none;" class="multis-values"></div>').find('div#'+b.settings._id+'_values');if(this.settings.infotext!='')b.values.append('<div class="multis-infotext">'+this.settings.infotext+'</div>');if(this.settings.mode=='select'){this.coolMultiple('init_select')}else if(this.settings.mode=='checkboxes'){this.coolMultiple('init_checkboxes')}},'init_select':function(){var b=this;b.find('option').each(function(){b.div.append('<p id="'+b.settings._id+'_o_'+e(this).val().replace('#','')+'" rel="'+e(this).val()+'">'+e(this).text()+'</p>');if(e(this).attr('selected')){b.coolMultiple('select',e(this).val())}});b.div.find('p').click(function(){var a=e(this).attr('rel').replace(b.settings._id+'_o_','');if(!e(this).hasClass('multis-selected')){b.coolMultiple('select',a)}else{b.coolMultiple('deselect',a)}})},'init_checkboxes':function(){var b=this;b.find('input[type="checkbox"]').each(function(){b.div.append('<p id="'+b.settings._id+'_o_'+e(this).val()+'">'+e(this).parent().text()+'</p>');if(e(this).attr('checked')){b.coolMultiple('select',e(this).val())}});b.div.find('p').click(function(){var a=e(this).attr('rel').replace(b.settings._id+'_o_','');if(!e(this).hasClass('multis-selected')){b.coolMultiple('select',a)}else{b.coolMultiple('deselect',a)}})},'select':function(o){var a=this;if(a.settings.mode=='select'){var b='option'}else if(a.settings.mode=='checkboxes'){var b='input'}var c=a.find(b+'[value="'+o+'"]');if(a.settings.mode=='select'){c.attr('selected','selected');var d=c.text()}else if(a.settings.mode=='checkboxes'){var d=c.parent().text();c.attr('checked','checked')}e('p#'+a.settings._id+'_o_'+o.replace('#','')).addClass('multis-selected');a.values.append('<p id="'+a.settings._id+'_os_'+o.replace('#','')+'">'+d+'<a class="multis-del" href="#">'+a.settings.delText+'</a></p>').find('a').click(function(){a.coolMultiple('deselect',o);return false});a.values.find('.multis-infotext').hide()},'deselect':function(o){var a=this;if(a.settings.mode=='select'){var b='option'}else if(a.settings.mode=='checkboxes'){var b='input'}var c=a.find(b+'[value="'+o+'"]');if(a.settings.mode=='select'){/*c.attr('selected','');*/c.removeAttr('selected');var d=c.text()}else if(a.settings.mode=='checkboxes'){var d=c.parent().text();c.attr('checked','')}e('p#'+a.settings._id+'_o_'+o.replace('#','')).removeClass('multis-selected');a.values.find('p#'+a.settings._id+'_os_'+o.replace('#','')).remove();if(a.values.find('p').length==0)a.values.find('.multis-infotext').show()}};e.fn.coolMultiple=function(a){if(f[a]){return f[a].apply(this,Array.prototype.slice.call(arguments,1))}else if(typeof a==='object'||!a){return f.init.apply(this,arguments)}else{if(console.log)console.log('Method '+a+' does not exist on jQuery.coolMultiple')}return this}})(jQuery);



/*
 * jQuery MultiSelect UI Widget 1.12
 * Copyright (c) 2011 Eric Hynds
 *
 * http://www.erichynds.com/jquery/jquery-ui-multiselect-widget/
 *
 * Depends:
 *   - jQuery 1.4.2+
 *   - jQuery UI 1.8 widget factory
 *
 * Optional:
 *   - jQuery UI effects
 *   - jQuery UI position utility
 *
 * Dual licensed under the MIT and GPL licenses:
 *   http://www.opensource.org/licenses/mit-license.php
 *   http://www.gnu.org/licenses/gpl.html
 *
*/
;(function($, undefined){

var multiselectID = 0;

$.widget("ech.multiselect", {
	
	// default options
	options: {
		header: true,
		height: 175,
		minWidth: 225,
		classes: '',
		checkAllText: 'Check all',
		uncheckAllText: 'Uncheck all',
		noneSelectedText: 'Select options',
		selectedText: '# selected',
		selectedList: 0,
		show: '',
		hide: '',
		autoOpen: false,
		multiple: true,
		position: {}
	},

	_create: function(){
		var el = this.element.hide(),
			o = this.options;
		
		this.speed = $.fx.speeds._default; // default speed for effects
		this._isOpen = false; // assume no
	
		var 
			button = (this.button = $('<button type="button"><span class="ui-icon ui-icon-triangle-2-n-s"></span></button>'))
				.addClass('ui-multiselect ui-widget ui-state-default ui-corner-all ui-widget-content vertex-input')
				.addClass( o.classes )
				.attr({ 'title':el.attr('title'), 'aria-haspopup':true, 'tabIndex':el.attr('tabIndex') }).height(32)
				.insertAfter( el ),
			
			buttonlabel = (this.buttonlabel = $('<span />'))
				.html( o.noneSelectedText )
				.appendTo( button ),
				
			menu = (this.menu = $('<div />'))
				.addClass('ui-multiselect-menu ui-widget ui-widget-content ui-corner-all')
				.addClass( o.classes )
				.appendTo( document.body ),
				
			header = (this.header = $('<div />'))
				.addClass('ui-widget-header ui-corner-all ui-multiselect-header ui-helper-clearfix')
				.appendTo( menu ),
				
			headerLinkContainer = (this.headerLinkContainer = $('<ul />'))
				.addClass('ui-helper-reset')
				.html(function(){
					if( o.header === true ){
						return '<li><a class="ui-multiselect-all" href="#"><span class="ui-icon ui-icon-check"></span><span>' + o.checkAllText + '</span></a></li><li><a class="ui-multiselect-none" href="#"><span class="ui-icon ui-icon-closethick"></span><span>' + o.uncheckAllText + '</span></a></li>';
					} else if(typeof o.header === "string"){
						return '<li>' + o.header + '</li>';
					} else {
						return '';
					}
				})
				.append('<li class="ui-multiselect-close"><a href="#" class="ui-multiselect-close"><span class="ui-icon ui-icon-circle-close"></span></a></li>')
				.appendTo( header ),
			
			checkboxContainer = (this.checkboxContainer = $('<ul />'))
				.addClass('ui-multiselect-checkboxes ui-helper-reset')
				.appendTo( menu );
		
		// perform event bindings
		this._bindEvents();
		
		// build menu
		this.refresh( true );
		
		// some addl. logic for single selects
		if( !o.multiple ){
			menu.addClass('ui-multiselect-single');
		}
	},
	
	_init: function(){
		if( this.options.header === false ){
			this.header.hide();
		}
		if( !this.options.multiple ){
			this.headerLinkContainer.find('.ui-multiselect-all, .ui-multiselect-none').hide();
		}
		if( this.options.autoOpen ){
			this.open();
		}
		if( this.element.is(':disabled') ){
			this.disable();
		}
	},
	
	refresh: function( init ){
		var el = this.element,
			o = this.options,
			menu = this.menu,
			checkboxContainer = this.checkboxContainer,
			optgroups = [],
			html = [],
			id = el.attr('id') || multiselectID++; // unique ID for the label & option tags
		
		// build items
		el.find('option').each(function( i ){
			var $this = $(this), 
				parent = this.parentNode,
				title = this.innerHTML,
				description = this.title,
				value = this.value,
				inputID = this.id || 'ui-multiselect-' + id + '-option-' + i,
				isDisabled = this.disabled,
				isSelected = this.selected,
				labelClasses = ['ui-corner-all'],
				optLabel;
			
			// is this an optgroup?
			if( parent.tagName.toLowerCase() === 'optgroup' ){
				optLabel = parent.getAttribute('label');
				
				// has this optgroup been added already?
				if( $.inArray(optLabel, optgroups) === -1 ){
					html.push('<li class="ui-multiselect-optgroup-label"><a href="#">' + optLabel + '</a></li>');
					optgroups.push( optLabel );
				}
			}
		
			if( isDisabled ){
				labelClasses.push('ui-state-disabled');
			}

			// browsers automatically select the first option
			// by default with single selects
			if( isSelected && !o.multiple ){
				labelClasses.push('ui-state-active');
			}
			
			html.push('<li class="' + (isDisabled ? 'ui-multiselect-disabled' : '') + '">');
			
			// create the label
			html.push('<label for="' + inputID + '" title="' + description + '" class="' + labelClasses.join(' ') + '">');
			html.push('<input id="' + inputID + '" name="multiselect_' + id + '" type="' + (o.multiple ? "checkbox" : "radio") + '" value="' + value + '" title="' + title + '"');

			// pre-selected?
			if( isSelected ){
				html.push(' checked="checked"');
				html.push(' aria-selected="true"');
			}

			// disabled?
			if( isDisabled ){
				html.push(' disabled="disabled"');
				html.push(' aria-disabled="true"');
			}

			// add the title and close everything off
			html.push(' /><span>' + title + '</span></label></li>');
		});
		
		// insert into the DOM
		checkboxContainer.html( html.join('') );

		// cache some moar useful elements
		this.labels = menu.find('label');
		
		// set widths
		this._setButtonWidth();
		this._setMenuWidth();
		
		// remember default value
		this.button[0].defaultValue = this.update();
		
		// broadcast refresh event; useful for widgets
		if( !init ){
			this._trigger('refresh');
		}
	},
	
	// updates the button text. call refresh() to rebuild
	update: function(){
		var o = this.options,
			$inputs = this.labels.find('input'),
			$checked = $inputs.filter('[checked]'),
			numChecked = $checked.length,
			value;
		
		if( numChecked === 0 ){
			value = o.noneSelectedText;
		} else {
			if($.isFunction( o.selectedText )){
				value = o.selectedText.call(this, numChecked, $inputs.length, $checked.get());
			} else if( /\d/.test(o.selectedList) && o.selectedList > 0 && numChecked <= o.selectedList){
				value = $checked.map(function(){ return $(this).next().text(); }).get().join(', ');
			} else {
				value = o.selectedText.replace('#', numChecked).replace('#', $inputs.length);
			}
		}
		
		this.buttonlabel.html( value );
		return value;
	},
	
	// binds events
	_bindEvents: function(){
		var self = this, button = this.button;
		
		function clickHandler(){
			self[ self._isOpen ? 'close' : 'open' ]();
			return false;
		}
		
		// webkit doesn't like it when you click on the span :(
		button
			.find('span')
			.bind('click.multiselect', clickHandler);
		
		// button events
		button.bind({
			click: clickHandler,
			keypress: function( e ){
				switch(e.which){
					case 27: // esc
					case 38: // up
					case 37: // left
						self.close();
						break;
					case 39: // right
					case 40: // down
						self.open();
						break;
				}
			},
			mouseenter: function(){
				if( !button.hasClass('ui-state-disabled') ){
					$(this).addClass('ui-state-hover');
				}
			},
			mouseleave: function(){
				$(this).removeClass('ui-state-hover');
			},
			focus: function(){
				if( !button.hasClass('ui-state-disabled') ){
					$(this).addClass('ui-state-focus');
				}
			},
			blur: function(){
				$(this).removeClass('ui-state-focus');
			}
		});

		// header links
		this.header
			.delegate('a', 'click.multiselect', function( e ){
				// close link
				if( $(this).hasClass('ui-multiselect-close') ){
					self.close();
			
				// check all / uncheck all
				} else {
					self[ $(this).hasClass('ui-multiselect-all') ? 'checkAll' : 'uncheckAll' ]();
				}
			
				e.preventDefault();
			});
		
		// optgroup label toggle support
		this.menu
			.delegate('li.ui-multiselect-optgroup-label a', 'click.multiselect', function( e ){
				e.preventDefault();
				
				var $this = $(this),
					$inputs = $this.parent().nextUntil('li.ui-multiselect-optgroup-label').find('input:visible:not(:disabled)'),
				    nodes = $inputs.get(),
				    label = $this.parent().text();
				
				// trigger event and bail if the return is false
				if( self._trigger('beforeoptgrouptoggle', e, { inputs:nodes, label:label }) === false ){
					return;
				}
				
				// toggle inputs
				self._toggleChecked(
					$inputs.filter('[checked]').length !== $inputs.length,
					$inputs
				);

				self._trigger('optgrouptoggle', e, {
				    inputs: nodes,
				    label: label,
				    checked: nodes[0].checked
				});
			})
			.delegate('label', 'mouseenter.multiselect', function(){
				if( !$(this).hasClass('ui-state-disabled') ){
					self.labels.removeClass('ui-state-hover');
					$(this).addClass('ui-state-hover').find('input').focus();
				}
			})
			.delegate('label', 'keydown.multiselect', function( e ){
				e.preventDefault();
				
				switch(e.which){
					case 9: // tab
					case 27: // esc
						self.close();
						break;
					case 38: // up
					case 40: // down
					case 37: // left
					case 39: // right
						self._traverse(e.which, this);
						break;
					case 13: // enter
						$(this).find('input')[0].click();
						break;
				}
			})
			.delegate('input[type="checkbox"], input[type="radio"]', 'click.multiselect', function( e ){
				var $this = $(this),
					val = this.value,
					checked = this.checked,
					tags = self.element.find('option');
				
				// bail if this input is disabled or the event is cancelled
				if( this.disabled || self._trigger('click', e, { value: val, text: this.title, checked: checked }) === false ){
					e.preventDefault();
					return;
				}

				// make sure the input has focus. otherwise, the esc key
				// won't close the menu after clicking an item.
				$this.focus();
				
				// toggle aria state
				$this.attr('aria-selected', checked);
				
				// change state on the original option tags
				tags.each(function(){
					if( this.value === val ){
						this.selected = checked;
					} else if( !self.options.multiple ){
						this.selected = false;
					}
				});
				
				// some additional single select-specific logic
				if( !self.options.multiple ){
					self.labels.removeClass('ui-state-active');
					$this.closest('label').toggleClass('ui-state-active', checked );
					
					// close menu
					self.close();
				}

				// fire change on the select box
				self.element.trigger("change");
				
				// setTimeout is to fix multiselect issue #14 and #47. caused by jQuery issue #3827
				// http://bugs.jquery.com/ticket/3827 
				setTimeout($.proxy(self.update, self), 10);
			});

		// close each widget when clicking on any other element/anywhere else on the page
		$(document).bind('mousedown.multiselect', function( e ){
			if(self._isOpen && !$.contains(self.menu[0], e.target) && !$.contains(self.button[0], e.target) && e.target !== self.button[0]){
				self.close();
			}
		});

		// deal with form resets.  the problem here is that buttons aren't
		// restored to their defaultValue prop on form reset, and the reset
		// handler fires before the form is actually reset.  delaying it a bit
		// gives the form inputs time to clear.
		$(this.element[0].form).bind('reset.multiselect', function(){
			setTimeout($.proxy(self.refresh, self), 10);
		});
	},

	// set button width
	_setButtonWidth: function(){
		var width = this.element.outerWidth(),
			o = this.options;
			
		if( /\d/.test(o.minWidth) && width < o.minWidth){
			width = o.minWidth;
		}
		
		// set widths
		this.button.width( width );
	},
	
	// set menu width
	_setMenuWidth: function(){
		var m = this.menu,
			width = this.button.outerWidth()-
				parseInt(m.css('padding-left'),10)-
				parseInt(m.css('padding-right'),10)-
				parseInt(m.css('border-right-width'),10)-
				parseInt(m.css('border-left-width'),10);
				
		m.width( width || this.button.outerWidth() );
	},
	
	// move up or down within the menu
	_traverse: function( which, start ){
		var $start = $(start),
			moveToLast = which === 38 || which === 37,
			
			// select the first li that isn't an optgroup label / disabled
			$next = $start.parent()[moveToLast ? 'prevAll' : 'nextAll']('li:not(.ui-multiselect-disabled, .ui-multiselect-optgroup-label)')[ moveToLast ? 'last' : 'first']();
		
		// if at the first/last element
		if( !$next.length ){
			var $container = this.menu.find('ul').last();
			
			// move to the first/last
			this.menu.find('label')[ moveToLast ? 'last' : 'first' ]().trigger('mouseover');
			
			// set scroll position
			$container.scrollTop( moveToLast ? $container.height() : 0 );
			
		} else {
			$next.find('label').trigger('mouseover');
		}
	},

	// This is an internal function to toggle the checked property and
	// other related attributes of a checkbox.
	//
	// The context of this function should be a checkbox; do not proxy it.
	_toggleState: function( prop, flag ){
		return function(){
			if( !this.disabled ) {
				this[ prop ] = flag;
			}

			if( flag ){
				this.setAttribute('aria-selected', true);
			} else {
				this.removeAttribute('aria-selected');
			}
		};
	},

	_toggleChecked: function( flag, group ){
		var $inputs = (group && group.length) ?
			group :
			this.labels.find('input'),

			self = this;

		// toggle state on inputs
		$inputs.each(this._toggleState('checked', flag));

		// give the first input focus
		$inputs.eq(0).focus();
		
		// update button text
		this.update();
		
		// gather an array of the values that actually changed
		var values = $inputs.map(function(){
			return this.value;
		}).get();

		// toggle state on original option tags
		this.element
			.find('option')
			.each(function(){
				if( !this.disabled && $.inArray(this.value, values) > -1 ){
					self._toggleState('selected', flag).call( this );
				}
			});

		// trigger the change event on the select
		if( $inputs.length ) {
			this.element.trigger("change");
		}
	},

	_toggleDisabled: function( flag ){
		this.button
			.attr({ 'disabled':flag, 'aria-disabled':flag })[ flag ? 'addClass' : 'removeClass' ]('ui-state-disabled');
		
		this.menu
			.find('input')
			.attr({ 'disabled':flag, 'aria-disabled':flag })
			.parent()[ flag ? 'addClass' : 'removeClass' ]('ui-state-disabled');
		
		this.element
			.attr({ 'disabled':flag, 'aria-disabled':flag });
	},
	
	// open the menu
	open: function( e ){
		var self = this,
			button = this.button,
			menu = this.menu,
			speed = this.speed,
			o = this.options;
		
		// bail if the multiselectopen event returns false, this widget is disabled, or is already open 
		if( this._trigger('beforeopen') === false || button.hasClass('ui-state-disabled') || this._isOpen ){
			return;
		}
		
		var $container = menu.find('ul').last(),
			effect = o.show,
			pos = button.offset();
		
		// figure out opening effects/speeds
		if( $.isArray(o.show) ){
			effect = o.show[0];
			speed = o.show[1] || self.speed;
		}
		
		// set the scroll of the checkbox container
		$container.scrollTop(0).height(o.height);
		
		// position and show menu
		if( $.ui.position && !$.isEmptyObject(o.position) ){
			o.position.of = o.position.of || button;
			
			menu
				.show()
				.position( o.position )
				.hide()
				.show( effect, speed );
		
		// if position utility is not available...
		} else {
			menu.css({ 
				top: pos.top + button.outerHeight(),
				left: pos.left
			}).show( effect, speed );
		}
		
		// select the first option
		// triggering both mouseover and mouseover because 1.4.2+ has a bug where triggering mouseover
		// will actually trigger mouseenter.  the mouseenter trigger is there for when it's eventually fixed
		this.labels.eq(0).trigger('mouseover').trigger('mouseenter').find('input').trigger('focus');
		
		button.addClass('ui-state-active');
		this._isOpen = true;
		this._trigger('open');
	},
	
	// close the menu
	close: function(){
		if(this._trigger('beforeclose') === false){
			return;
		}
	
		var o = this.options, effect = o.hide, speed = this.speed;
		
		// figure out opening effects/speeds
		if( $.isArray(o.hide) ){
			effect = o.hide[0];
			speed = o.hide[1] || this.speed;
		}
	
		this.menu.hide(effect, speed);
		this.button.removeClass('ui-state-active').trigger('blur').trigger('mouseleave');
		this._isOpen = false;
		this._trigger('close');
	},

	enable: function(){
		this._toggleDisabled(false);
	},
	
	disable: function(){
		this._toggleDisabled(true);
	},
	
	checkAll: function( e ){
		this._toggleChecked(true);
		this._trigger('checkAll');
	},
	
	uncheckAll: function(){
		this._toggleChecked(false);
		this._trigger('uncheckAll');
	},
	
	getChecked: function(){
		return this.menu.find('input').filter('[checked]');
	},
	
	destroy: function(){
		// remove classes + data
		$.Widget.prototype.destroy.call( this );
		
		this.button.remove();
		this.menu.remove();
		this.element.show();
		
		return this;
	},
	
	isOpen: function(){
		return this._isOpen;
	},
	
	widget: function(){
		return this.menu;
	},
	
	// react to option changes after initialization
	_setOption: function( key, value ){
		var menu = this.menu;
		
		switch(key){
			case 'header':
				menu.find('div.ui-multiselect-header')[ value ? 'show' : 'hide' ]();
				break;
			case 'checkAllText':
				menu.find('a.ui-multiselect-all span').eq(-1).text(value);
				break;
			case 'uncheckAllText':
				menu.find('a.ui-multiselect-none span').eq(-1).text(value);
				break;
			case 'height':
				menu.find('ul').last().height( parseInt(value,10) );
				break;
			case 'minWidth':
				this.options[ key ] = parseInt(value,10);
				this._setButtonWidth();
				this._setMenuWidth();
				break;
			case 'selectedText':
			case 'selectedList':
			case 'noneSelectedText':
				this.options[key] = value; // these all needs to update immediately for the update() call
				this.update();
				break;
			case 'classes':
				menu.add(this.button).removeClass(this.options.classes).addClass(value);
				break;
		}
		
		$.Widget.prototype._setOption.apply( this, arguments );
	}
});

})(jQuery);


/* jshint forin:true, noarg:true, noempty:true, eqeqeq:true, boss:true, undef:true, curly:true, browser:true, jquery:true */
/*
 * jQuery MultiSelect UI Widget Filtering Plugin 1.4
 * Copyright (c) 2011 Eric Hynds
 *
 * http://www.erichynds.com/jquery/jquery-ui-multiselect-widget/
 *
 * Depends:
 *   - jQuery UI MultiSelect widget
 *
 * Dual licensed under the MIT and GPL licenses:
 *   http://www.opensource.org/licenses/mit-license.php
 *   http://www.gnu.org/licenses/gpl.html
 *
*/
(function($){
	var rEscape = /[\-\[\]{}()*+?.,\\\^$|#\s]/g;
	
	$.widget("ech.multiselectfilter", {
		
		options: {
			label: "Filter:",
			width: null, /* override default width set in css file (px). null will inherit */
			placeholder: "Enter keywords",
			autoReset: false
		},
		
		_create: function(){
			var self = this,
				opts = this.options,
				instance = (this.instance = $(this.element).data("multiselect")),
				
				// store header; add filter class so the close/check all/uncheck all links can be positioned correctly
				header = (this.header = instance.menu.find(".ui-multiselect-header").addClass("ui-multiselect-hasfilter")),
				
				// wrapper elem
				wrapper = (this.wrapper = $('<div class="ui-multiselect-filter">'+(opts.label.length ? opts.label : '')+'<input placeholder="'+opts.placeholder+'" type="search"' + (/\d/.test(opts.width) ? 'style="width:'+opts.width+'px"' : '') + ' /></div>').prependTo( this.header ));

			// reference to the actual inputs
			this.inputs = instance.menu.find('input[type="checkbox"], input[type="radio"]');
			
			// build the input box
			this.input = wrapper
			.find("input")
			.bind({
				keydown: function( e ){
					// prevent the enter key from submitting the form / closing the widget
					if( e.which === 13 ){
						e.preventDefault();
					}
				},
				keyup: $.proxy(self._handler, self),
				click: $.proxy(self._handler, self)
			});
			
			// cache input values for searching
			this.updateCache();
			
			// rewrite internal _toggleChecked fn so that when checkAll/uncheckAll is fired,
			// only the currently filtered elements are checked
			instance._toggleChecked = function(flag, group){
				var $inputs = (group && group.length) ?
						group :
						this.labels.find('input'),
					
					_self = this,

					// do not include hidden elems if the menu isn't open.
					selector = self.instance._isOpen ?
						":disabled, :hidden" :
						":disabled";

				$inputs = $inputs.not( selector ).each(this._toggleState('checked', flag));
				
				// update text
				this.update();
				
				// figure out which option tags need to be selected
				var values = $inputs.map(function(){
					return this.value;
				}).get();
				
				// select option tags
				this.element
					.find('option')
					.filter(function(){
						if( !this.disabled && $.inArray(this.value, values) > -1 ){
							_self._toggleState('selected', flag).call( this );
						}
					});
			};
			
			// rebuild cache when multiselect is updated
			var doc = $(document).bind("multiselectrefresh", function(){
				self.updateCache();
				self._handler();
			});

			// automatically reset the widget on close?
			if(this.options.autoReset) {
				doc.bind("multiselectclose", $.proxy(this._reset, this));
			}
		},
		
		// thx for the logic here ben alman
		_handler: function( e ){
			var term = $.trim( this.input[0].value.toLowerCase() ),
			
				// speed up lookups
				rows = this.rows, inputs = this.inputs, cache = this.cache;
			
			if( !term ){
				rows.show();
			} else {
				rows.hide();
				
				var regex = new RegExp(term.replace(rEscape, "\\$&"), 'gi');
				
				this._trigger( "filter", e, $.map(cache, function(v, i){
					if( v.search(regex) !== -1 ){
						rows.eq(i).show();
						return inputs.get(i);
					}
					
					return null;
				}));
			}

			// show/hide optgroups
			this.instance.menu.find(".ui-multiselect-optgroup-label").each(function(){
				var $this = $(this);
				var isVisible = $this.nextUntil('.ui-multiselect-optgroup-label').filter(function(){
				  return $.css(this, "display") !== 'none';
				}).length;
				
				$this[ isVisible ? 'show' : 'hide' ]();
			});
		},

		_reset: function() {
			this.input.val('').trigger('keyup');
		},
		
		updateCache: function(){
			// each list item
			this.rows = this.instance.menu.find(".ui-multiselect-checkboxes li:not(.ui-multiselect-optgroup-label)");
			
			// cache
			this.cache = this.element.children().map(function(){
				var self = $(this);
				
				// account for optgroups
				if( this.tagName.toLowerCase() === "optgroup" ){
					self = self.children();
				}
				
				return self.map(function(){
					return this.innerHTML.toLowerCase();
				}).get();
			}).get();
		},
		
		widget: function(){
			return this.wrapper;
		},
		
		destroy: function(){
			$.Widget.prototype.destroy.call( this );
			this.input.val('').trigger("keyup");
			this.wrapper.remove();
		}
	});
})(jQuery);
